@@ -11,6 +11,14 @@
         if (!slot(x, "vol"))
             x <- getvolumeUD(x, standardize=standardize)
         tmp <- as.data.frame(x)[,1]
+        ## Check that all the contour are within the study area limits
+        gp <- gridparameters(x)[,3]
+        tmpm <- matrix(tmp, ncol=gp[2], nrow=gp[1], byrow = TRUE)
+        ma <- min(c(tmpm[c(1:nrow(tmpm)), c(1,ncol(tmpm))],
+                    tmpm[c(1,nrow(tmpm)), c(1:ncol(tmpm))]))
+        if (any(percent>=ma))
+            warning(paste("The grid is too small to allow the estimation of home-range\nfor the following value of percent: ", paste(percent[percent>=ma], collapse = ","), ". You should rerun kernelUD with a larger extent parameter", sep=""))
+
         area <- unlist(lapply(percent, function(o) length(tmp[tmp<=o])*(gridparameters(x)[1,2]^2)))
         if (unin == "m") {
             if (unout == "ha")
